#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-aeson
version:              1.1.1
visibility:           public
id:                   lens-aeson-1.1.1-6gIBhxBSp7UK9bxNmK4XN0
key:                  lens-aeson-1.1.1-6gIBhxBSp7UK9bxNmK4XN0
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Numeric
abi:                  002bfb59de0a9bd9cce59308ca8dbd7b
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-8.10.5/site-local/lens-aeson-1.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/lens-aeson-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/lens-aeson-1.1.1
hs-libraries:         HSlens-aeson-1.1.1-6gIBhxBSp7UK9bxNmK4XN0
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    bytestring-0.10.12.0 lens-5.0.1-9j09gzxg2dR5Wmd3U39g28
    scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX text-1.2.4.1
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

